@@ -466,6 +466,16 @@ class Config(object):
         return res
 
     def _get_r(self, prefix, platform):
+        if platform.startswith('win'):
+            res = join(prefix, 'Scripts', 'R.exe')
+            # MRO test:
+            if not os.path.exists(res):
+                res = join(prefix, 'bin', 'R.exe')
+        else:
+            res = join(prefix, 'bin', 'R')
+        return res
+
+    def _get_rscript(self, prefix, platform):
         if platform.startswith('win'):
             res = join(prefix, 'Scripts', 'Rscript.exe')
             # MRO test:
@@ -590,6 +600,9 @@ class Config(object):
     def r_bin(self, prefix, platform):
         return self._get_r(prefix, platform)
 
+    def rscript_bin(self, prefix, platform):
+        return self._get_rscript(prefix, platform)
+
     @property
     def info_dir(self):
         """Path to the info dir in the build prefix, where recipe metadata is stored"""
