@@ -161,7 +161,9 @@ def eval_selector(selector_string, namespace, variants_in_place):
     except NameError as e:
         missing_var = parseNameNotFound(e)
         if variants_in_place:
-            print("Warning: Treating unknown selector \'" + missing_var + "\' as if it was False.")
+            log = utils.get_logger(__name__)
+            log.debug("Treating unknown selector \'" + missing_var +
+                      "\' as if it was False.")
         next_string = selector_string.replace(missing_var, "False")
         return eval_selector(next_string, namespace, variants_in_place)
 
@@ -1801,7 +1803,10 @@ class MetaData(object):
                     utils.rm_rf(om.config.work_dir)
                     provide(om)
                     om.parse_again()
-                om.parse_until_resolved(allow_no_other_outputs=True, bypass_env_check=True)
+                try:
+                    om.parse_until_resolved(allow_no_other_outputs=True, bypass_env_check=True)
+                except SystemExit:
+                    pass
                 outputs = get_output_dicts_from_metadata(om)
 
                 try:
