@@ -21,7 +21,8 @@ def _error_exit(exit_message):
 
 def rewrite_script(fn, prefix):
     """Take a file from the bin directory and rewrite it into the python-scripts
-    directory after it passes some sanity checks for noarch pacakges"""
+    directory with the same permissions after it passes some sanity checks for
+    noarch pacakges"""
 
     # Load and check the source file for not being a binary
     src = join(prefix, 'Scripts' if ISWIN else 'bin', fn)
@@ -30,6 +31,7 @@ def rewrite_script(fn, prefix):
             data = fi.read()
         except UnicodeDecodeError:  # file is binary
             _error_exit("Noarch package contains binary script: %s" % fn)
+    src_mode = os.stat(src).st_mode
     os.unlink(src)
 
     # Get rid of '-script.py' suffix on Windows
@@ -39,8 +41,10 @@ def rewrite_script(fn, prefix):
     # Rewrite the file to the python-scripts directory
     dst_dir = join(prefix, 'python-scripts')
     _force_dir(dst_dir)
-    with open(join(dst_dir, fn), 'w') as fo:
+    dst = join(dst_dir, fn)
+    with open(dst, 'w') as fo:
         fo.write(data)
+    os.chmod(dst, src_mode)
     return fn
 
 
@@ -81,10 +85,11 @@ def handle_file(f, d, prefix):
     # Include examples in the metadata doc
     elif f.startswith(('Examples/', 'Examples\\')):
         d['Examples'].append(f[9:])
+    # No special treatment for other files
+    # leave them as-is
     else:
         log = logging.getLogger(__name__)
-        log.warn("Don't know how to handle file: %s.  Omitting it from package." % f)
-        os.unlink(path)
+        log.debug("Don't know how to handle file: %s.  Including it as-is." % f)
 
 
 def populate_files(m, files, prefix, entry_point_scripts=None):
@@ -106,14 +111,13 @@ def populate_files(m, files, prefix, entry_point_scripts=None):
     if entry_point_scripts:
         for entry_point in entry_point_scripts:
             src = join(prefix, entry_point)
-            os.unlink(src)
+            if os.path.isfile(src):
+                os.unlink(src)
 
     return d
 
 
 def transform(m, files, prefix):
-    assert 'py_' in m.dist()
-
     bin_dir = join(prefix, 'bin')
     _force_dir(bin_dir)
 
